@@ -1,36 +1,30 @@
 # -*- python -*-
-# -*- coding: utf-8 -*-
 #
-#  This file is part of the CNO software
+#  This file is part of the rtools package
 #
-#  Copyright (c) 2011-2012 - EBI
+#  Copyright (c) 2011-2012 - EBI - EMBL
 #
-#  File author(s): Thomas Cokelaer <cokelaer@ebi.ac.uk>
+#  File author(s): Thomas Cokelaer (cokelaer@ebi.ac.uk)
 #
-#  Distributed under the GPLv2 License.
+#  Distributed under the GPL License.
 #  See accompanying file LICENSE.txt or copy at
-#      http://www.gnu.org/licenses/gpl-2.0.html
+#      http://www.gnu.org/licenses/gpl-3.0.html
 #
-#  CNO website: http://www.ebi.ac.uk/saezrodriguez/software.html
+#  RTools website: http://www.ebi.ac.uk/~cokelaer/rtools
 #
 ##############################################################################
 # $Id: tools.py 2193 2012-08-22 21:39:17Z cokelaer $
 """Utilities for cnolab.wrapper
 
-Created by Thomas Cokelaer <cokelaer@ebi.ac.uk>
-Copyright (c) 2011. GPL
+:author: Thomas Cokelaer <cokelaer@ebi.ac.uk>
+:licence: copyright (2012). GPL
 
-.. testsetup:: *
-
-    from rpy2.robjects.packages import importr
-    import numpy
-    from cno import *
 
 """
 __author__ = """\n""".join(['Thomas Cokelaer <cokelaer@ebi.ac.uk'])
 
 __all__ = ['Rnames2attributes',  'buildDocString', "RManualToDocString",  
-     "RConvertor", "convertor"]
+     "RConvertor", "convertor", "rcode"]
 
 import logging
 import os
@@ -39,8 +33,22 @@ from rpy2 import robjects
 from rpy2.robjects import rinterface
 from rpy2.robjects.packages import importr
 from rpy2.robjects import r
+
 from error import Rwarning, RRuntimeError
 
+
+def rcode(code):
+    """A simple alias to the :func:`rpy2.robject.r` function.
+
+    ::
+
+        res = rcode("list(a=c(1,2), b=2)")
+
+    """
+    from rpy2.robjects import r
+    res = r(code)
+    return res
+
  
 # decorator with no arguments for a function with arguments
 def Rnames2attributes(f):
@@ -87,6 +95,10 @@ def Rnames2attributes(f):
         >>> m.DAcol #doctest: +SKIP
         <FloatVector - Python:0x339c128 / R:0x7fab5c721518>
         [5.000000, 6.000000, 7.000000, ..., 9.000000, 10.000000, 11.000000]
+
+
+    .. warning:: this is not recursive. So only the first level is accessible with
+        attributes.
     """
     def wrap(*args, **kargs):
         res = f(*args, **kargs)
@@ -270,7 +282,7 @@ def buildDocString(base, name):
     """scan manual from a R function and transform it into a docstring.
 
 
-    .. seealso:: :func:`rtools.rools.RManualToDocString`
+    .. seealso:: :class:`rtools.rools.RManualToDocString`
 
     """
     try:
@@ -287,9 +299,11 @@ class RConvertor(object):
     """The RConverter ease the conversion of python objects into 
     R objects.
 
+    r = Convertor()
+    r.convert(None)
+    r.convert([1,2,3])
 
-    if list and type is none, check the type of each element that must be the same
-    as first.
+    See :meth:`convert` for details
     """
     def __init__(self): 
         pass
@@ -297,6 +311,23 @@ class RConvertor(object):
     def convert(self, data, forcetype=None):
         """convert simple python object to R object
 
+        :param data: the data to convert
+        :param forcetype: if data is a list, by default, the conversion is made
+            according to the type of the first element of the list. You can
+            force the type to be different with this argument (e.g.,
+            forcetype=str)
+
+        * if data is None, return a R object NULL
+        * if data is a list:
+            * if type of first element is integer, returns a IntVector
+            * if type of first element is float, returns a FloatVector
+            * if type of first element is str, returns a StrVector
+            * if type of first element is complex, returns a ComplexVector
+            * if type of first element is bool, returns a BoolVector
+        * else return the data itself (assume it is already a R object)
+
+
+    
         """
         if data == None:
             return robjects.NULL
@@ -324,24 +355,23 @@ class RConvertor(object):
             return data
 
 
-
+#: alias to the method convert of RConvertor class
 convertor = RConvertor().convert
 
 
 
 
-"""
-rpy2.robjects.array                        
-rpy2.robjects.NA_Complex
-rpy2.robjects.Array                        
-rpy2.robjects.NA_Integer
-rpy2.robjects.NA_Logical
-rpy2.robjects.DataFrame                    
-rpy2.robjects.Matrix 
-rpy2.robjects.NA_Character                 
-rpy2.robjects.vectors
-rpy2.robjects.NA_Real
-rpy2.robjects.FactorVector       
-rpy2.robjects.ListVector   
-rpy2.robjects.Vector
-"""
+#rpy2.robjects.array
+#rpy2.robjects.NA_Complex
+#rpy2.robjects.Array
+#rpy2.robjects.NA_Integer
+#rpy2.robjects.NA_Logical
+#rpy2.robjects.DataFrame                    
+#rpy2.robjects.Matrix 
+#rpy2.robjects.NA_Character                 
+#rpy2.robjects.vectors
+#rpy2.robjects.NA_Real
+#rpy2.robjects.FactorVector       
+#rpy2.robjects.ListVector   
+#rpy2.robjects.Vector
+
